@@ -41,6 +41,8 @@ class Bar:
 
 	def __init__(self, key = 'C', meter=(4,4)):
 
+		if type(key) == str:
+			key = Note(key)
 		self.key = key
 		self.set_meter(meter)	
 		self.empty()
