@@ -89,6 +89,10 @@ class Composition:
 		"""Overloads the [] = notation """
 		self.tracks[index] = value
 
+	def __len__(self):
+		"""Overloads the len() functions"""
+		return len(self.tracks)
+
 	def __repr__(self):
 		"""String representation of the class"""
 		result = ""
