@@ -19,7 +19,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ================================================================================
-	
+	The	Suite class is a datastructure that stores Composition objects.
 
 ================================================================================
 
@@ -29,16 +29,41 @@ class Suite:
 
 	title = 'Untitled'
 	subtitle = ''
+	author = ''
+	email = ''
 	compositions = []
 
 	def __init__(self):
 		pass
 
 	def add_composition(self, composition):
-		pass
+		"""Adds a composition to the suite"""
+		# Throw exception
+		if not ( hasattr ( composition, "tracks") ):
+			return False
+		self.compositions.append(composition)
 
 	def set_author(self, author, email = ''):
-		pass
+		"""Sets the author of the suite"""
+		self.author = author
+		self.email = email
 
 	def set_title(self, title, subtitle = ''):
-		pass
+		"""Sets the title and the subtitle of the suite"""
+		self.title = title
+		self.subtitle = subtitle
+
+	def __len__(self):
+		"""Overloads the len() function"""
+		return len(self.compositions)
+
+	def __getitem__(self, index):
+		"""Overloads the [] notation"""
+		return self.compositions[index]
+
+	def __setitem__(self, index, value):
+		"""Overloads the [] = notation"""
+		# Throw exception
+		if not ( hasattr ( value, "tracks") ):
+			return False
+		self.compositions[index] = value
